@@ -24,4 +24,19 @@ reporter = get_preprocess_reporter(algorithm_manager_host, logger, None)
 
 def open_reporter() -> Reporter:
     """Get a reporter instance for reporting status updates to the Algorithm Manager"""
-    return reporter
\ No newline at end of file
+    return reporter
+
+def get_logger(logging_level=logging.INFO) -> logging.Logger:
+    return EPAlgorithmLogger(__name__, level=logging_level)
+
+class EPAlgorithmLogger(logging.Logger):
+    def __init__(self, name, level=logging.NOTSET):
+        logging.Logger.__init__(self, name, level)
+        self._reporter = reporter.open()
+
+    def _log(self, level, msg, args, exc_info=None, extra=None, stack_info=False,
+             stacklevel=1):
+        self._reporter.report(msg)
+
+    def __del__(self):
+        self._reporter.close()
\ No newline at end of file
