@@ -6,15 +6,21 @@ class Reporter:
 
     def _print(self, message):
         self._logger.info(message)
+    
+    def open(self) -> "Reporter":
+        return self
+    
+    def close(self):
+        return
         
     def report(self, message: str) -> bool:
         raise NotImplementedError
     
     def __enter__(self):
-        return self
+        return self.open()
     
     def __exit__(self, type, value, tb):
-        return
+        return self.close()
 
 class ReporterConnectionDetails:
     def __init__(self,
